@@ -20,13 +20,10 @@
  * Copyright 2008 - 2014 Red Hat, Inc.
  */
 
-#include "config.h"
+#include "nm-default.h"
 
 #include <string.h>
 
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-
 #include "page-mobile.h"
 #include "nm-connection-editor.h"
 #include "nma-mobile-wizard.h"
